owls-app
========

Browse echelle spectra of low-mass stars from the Olin Wilson Legacy Survey (OWLS).

Getting started
---------------

Installation
^^^^^^^^^^^^

.. code-block:: bash

    python -m pip install owls-app

Run the app
^^^^^^^^^^^

To run the interactive tool, run:

.. code-block:: bash

    owls-app


Multiple sessions
^^^^^^^^^^^^^^^^^

If you already have an instance of `solara` or `whoseline` running, you can
launch a second one by specifying a different port:

.. code-block:: bash

    owls-app --port 1234

